@@ -29,47 +29,52 @@ module.exports = function (app) {
         if (types.length > 1) {
             saved = true;
         }
-        java.newInstancePromise("nylon.report.iReport")
-            .then(function (rp) {
-                //var iReport = java.import("nylon.report.iReport");
-                reportName = work_dir + "/app/reports/" + reportName;
-                //var rp = new iReport();
-                if (parameters) {
-                    parameters["SUBREPORT_DIR"] = work_dir + "/app/reports/";
-                    //parameters["REPORT_LOCALE"]="th-TH";
-                    // parameters["REPORT_TIME_ZONE"]="asia/bangkok";
-
-                } else {
-                    parameters = {
-                        "SUBREPORT_DIR": work_dir + "/app/reports/"
-                        //"REPORT_TIME_ZONE":"asia/bangkok",
-                        // "REPORT_LOCALE":"th-TH"
-                    };
-                }
-                // console.log(rp);
-                var outname = "";
-                if (parameters.OUTPUT_NAME != undefined && parameters.OUTPUT_NAME != "") {
-                    outname = parameters.OUTPUT_NAME;
-                }
-
-
-                rp.export(reportName, type, JSON.stringify(datas), JSON.stringify(parameters),
-                    function (err, buff) {
-                        if (err) {
-                            self.send(err);
-                        } else {
-                            var buffer = Buffer.from(buff, "hex");
-                            self.responseFile(buffer, type, saved, outname);
-                        }
-
-                    }
-                );
-            }).catch(function (err) {
+        java.newInstance("nylon.report.iReport", function (err, rp) {
+            if (err) {
                 console.log(err);
                 Object.keys(cluster.workers).forEach((id) => {
                     cluster.workers[id].process.kill();
                 });
-            });
+            }
+           // console.log(rp);
+
+
+            reportName = work_dir + "/app/reports/" + reportName;
+            //var rp = new iReport();
+            if (parameters) {
+                parameters["SUBREPORT_DIR"] = work_dir + "/app/reports/";
+                //parameters["REPORT_LOCALE"]="th-TH";
+                // parameters["REPORT_TIME_ZONE"]="asia/bangkok";
+
+            } else {
+                parameters = {
+                    "SUBREPORT_DIR": work_dir + "/app/reports/"
+                    //"REPORT_TIME_ZONE":"asia/bangkok",
+                    // "REPORT_LOCALE":"th-TH"
+                };
+            }
+            // console.log(rp);
+            var outname = "";
+            if (parameters.OUTPUT_NAME != undefined && parameters.OUTPUT_NAME != "") {
+                outname = parameters.OUTPUT_NAME;
+            }
+
+
+            rp.export(reportName, type, JSON.stringify(datas), JSON.stringify(parameters),
+                function (err, buff) {
+                    if (err) {
+                        self.send(err);
+                    } else {
+                        var buffer = Buffer.from(buff, "hex");
+                        self.responseFile(buffer, type, saved, outname);
+                    }
+
+                }
+            );
+            // new list
+        });
+
+      
 
     }
 
