@@ -26,38 +26,38 @@ module.exports = function (app) {
                 console.log("jdbc first time");
 
                 //var JDBCConnect = java.import("nylon.data.JDBCConnect");
-                java.newInstancePromise("nylon.data.JDBCConnect")
-                    .then(function (jdbc) {
-                       // jdbc = new JDBCConnect();
-                        if (config.jdbc) {
-                            async.each(config.jdbc, function (conn, next) {
-                                logger.info("JDBCConnect :: " + conn.name);
-                                try {
-                                    jdbc.addConnection(conn.name, conn.driver, conn.url, conn.user, conn.password
-                                        , function (err, data) {
-                                            console.log(data);
-                                            next();
-                                        }
-                                    );
-                                } catch (error) {
-                                    next();
-                                }
-                            }, function (err) {
-                                jdbc.query(driver, sql, parameters, function (err, data) {
-                                    callback(err, data);
-                                });
-                            });
-                        } else {
-                            callback({ error: "plase check jdbc config" }, {});
-                        }
-                    }).catch(function (err) {
+                java.newInstance("nylon.data.JDBCConnect", function (err, jdbc) {
+                    if (err) {
                         console.log(err);
                         Object.keys(cluster.workers).forEach((id) => {
                             cluster.workers[id].process.kill();
                         });
-                    });
+                    }
 
+                    if (config.jdbc) {
+                        async.each(config.jdbc, function (conn, next) {
+                            logger.info("JDBCConnect :: " + conn.name);
+                            try {
+                                jdbc.addConnection(conn.name, conn.driver, conn.url, conn.user, conn.password
+                                    , function (err, data) {
+                                        console.log(data);
+                                        next();
+                                    }
+                                );
+                            } catch (error) {
+                                next();
+                            }
+                        }, function (err) {
+                            jdbc.query(driver, sql, parameters, function (err, data) {
+                                callback(err, data);
+                            });
+                        });
+                    } else {
+                        callback({ error: "plase check jdbc config" }, {});
+                    }
 
+                });
+               
 
 
 
